package cz.uhk.fim.denotevrenychdveri;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;
import android.support.design.widget.NavigationView;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.view.GravityCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;


import cz.uhk.fim.denotevrenychdveri.fragments.ContactFragment;
import cz.uhk.fim.denotevrenychdveri.fragments.EventFragment;
import cz.uhk.fim.denotevrenychdveri.fragments.InformationFragment;


public class MainActivity extends AppCompatActivity
        implements NavigationView.OnNavigationItemSelectedListener {

    //final YouTubeInitializationResult youTubeTestApp = YouTubeApiServiceUtil.isYouTubeApiServiceAvailable(this);

    public static final String PREF_FILE_NAME = "drawer_check";
    public static final String KEY_USER_LEARNED_DRAWER = "user_learned_drawer";
    protected DrawerLayout mDrawer;
    private boolean mUserLearnedDrawer;
    private boolean mFromSavedInstance;

    private Toolbar toolbar;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //condicianal if user start aplication for first time
        mUserLearnedDrawer = Boolean.valueOf(readFromPreferences(this,PREF_FILE_NAME,"false"));
        if(savedInstanceState!=null){
            mFromSavedInstance=true;
        }


        toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);



        mDrawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(
                this, mDrawer, toolbar, R.string.navigation_drawer_open, R.string.navigation_drawer_close){
            @Override
            public void onDrawerOpened(View drawerView) {
                super.onDrawerOpened(drawerView);
                if (!mUserLearnedDrawer){
                    mUserLearnedDrawer = true;
                    saveToPreferences(MainActivity.this,PREF_FILE_NAME,mUserLearnedDrawer+"");
                }
            }

            @Override
            public void onDrawerClosed(View drawerView) {
                super.onDrawerClosed(drawerView);
            }
        };

        if (!mUserLearnedDrawer && !mFromSavedInstance){
            mDrawer.openDrawer(GravityCompat.START,true);
        }


        mDrawer.addDrawerListener(toggle);
        toggle.syncState();

        NavigationView navigationView = (NavigationView) findViewById(R.id.nav_view);
        navigationView.setNavigationItemSelectedListener(this);


        getSupportFragmentManager().addOnBackStackChangedListener(new FragmentManager.OnBackStackChangedListener() {
            @Override
            public void onBackStackChanged() {
                Toast.makeText(MainActivity.this,"stack change", Toast.LENGTH_SHORT).show();
                //getSupportActionBar().setDisplayHomeAsUpEnabled(true);

            }
        });
    }



    @Override
    public void onBackPressed() {
        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        if (drawer.isDrawerOpen(GravityCompat.START)) {
            drawer.closeDrawer(GravityCompat.START);
        } else {
            super.onBackPressed();
        }



    }



     @Override
    public boolean onNavigationItemSelected(MenuItem item) {
        // Handle navigation view item clicks here.
         int id = item.getItemId();
         FragmentManager fragmentManager = getSupportFragmentManager();
         resetActivityLayouts();
         if (id == R.id.nav_informations) {
            Fragment infoFragment = new InformationFragment();
             fragmentManager
                     .beginTransaction()
                     .replace(R.id.content_fragment, infoFragment, infoFragment.getTag())
                     .commit();
            toolbar.setTitle(R.string.informations);

        } else if (id == R.id.nav_events) {
             Fragment eventFragment = new EventFragment();
             fragmentManager
                     .beginTransaction()
                     .replace(R.id.content_fragment, eventFragment)
                     .commit();
             toolbar.setTitle(R.string.events);


         } else if (id == R.id.nav_video) {
             //Fragment videoFragment = new VideoFragment();
         /*    fragmentManager
                     .beginTransaction()
                     .replace(R.id.content_fragment, VideoFragment.newInstance("gQngvUm8NaY"))
                     .commit();*/
             toolbar.setTitle(R.string.video);
             final Intent fragIntent = new Intent(MainActivity.this, VideoFragmentActivity.class);
             fragIntent.putExtra(VideoFragmentActivity.KEY_VIDEO_ID, "gQngvUm8NaY");
             startActivity(fragIntent);

           //  Intent intent = YouTubeStandalonePlayer.createVideoIntent(this, "AIzaSyACk4Z8OJIutGb6fA0FcINYZ6Wt36RB8hs", "gQngvUm8NaY", 0, true, false);
          //   startActivity(intent);

        } else if (id == R.id.nav_contacts) {
             Fragment contactFragment = new ContactFragment();
             fragmentManager
                     .beginTransaction()
                     .replace(R.id.content_fragment, contactFragment)
                     .commit();
             toolbar.setTitle(R.string.contacts);

         } else if (id == R.id.nav_map) {

             toolbar.setTitle(R.string.map_with_route);
             final Intent fragIntent = new Intent(MainActivity.this, MapsActivity.class);
             startActivity(fragIntent);



        } else if (id == R.id.nav_facebook) {
             String facebookPageURL = "https://www.facebook.com/n/?fim.uhk.cz";
             Intent browserIntent = new Intent(Intent.ACTION_VIEW, Uri.parse(facebookPageURL));
             startActivity(browserIntent);

        } else if (id == R.id.nav_youtube) {
             String youtubePageURL = "https://www.youtube.com/channel/UCGZ3E3NXQW0_rmjfEy0foiA";
             Intent intent = new Intent(Intent.ACTION_VIEW);
             intent.setData(Uri.parse(youtubePageURL));
             startActivity(intent);

        } else if (id == R.id.nav_instagram) {
             String instagramPageURL = "https://www.instagram.com/_u/fim.uhk.cz/";
             Intent intent = new Intent(Intent.ACTION_VIEW);
             intent.setData(Uri.parse(instagramPageURL));
             startActivity(intent);
        }

        DrawerLayout drawer = (DrawerLayout) findViewById(R.id.drawer_layout);
        drawer.closeDrawer(GravityCompat.START);
        return true;
    }

    public static void saveToPreferences(Context context, String preferenceName, String preferenceValue){
        SharedPreferences sharedPreferences = context.getSharedPreferences(PREF_FILE_NAME,Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = sharedPreferences.edit();
        editor.putString(preferenceName,preferenceValue);
        editor.apply();
    }
    public static String readFromPreferences(Context context, String preferenceName, String defaultValue){
        SharedPreferences sharedPreferences = context.getSharedPreferences(PREF_FILE_NAME,Context.MODE_PRIVATE);
        return sharedPreferences.getString(preferenceName,defaultValue);
    }

    protected void resetActivityLayouts(){
        View view = findViewById(R.id.video_fragment);
        if (view != null){
            view.setVisibility(View.GONE);
        }
        view = findViewById(R.id.map_fragment);
        if (view != null){
            view.setVisibility(View.GONE);
        }
        view = findViewById(R.id.information_intro);
        if (view != null){
            view.setVisibility(View.GONE);
        }
    }
}
